==> ceonmedia-0.3.0.tar.gz: ceonmedia-0.3.0/tests/_tests_json_io/test_project.py <==
import logging
import pytest
from typing import Union
from uuid import UUID, uuid4
from pathlib import Path
from ceonstock import CstockProject
from ceonstock import json_io
from ceonstock import errors

logger = logging.getLogger(__name__)


def _get_json_files_in_dir(dir_to_read: Union[str, Path]) -> list[Path]:
    if not Path(dir_to_read).is_dir():
        raise Exception(
            f"Could not get test files, dir does not exist: {dir_to_read}"
        )
    p = Path(dir_to_read).glob("**/*")
    files = [x for x in p if x.is_file()]
    if not files:
        raise Exception(f"No files found for testing in path: {dir_to_read}")
    return files


TEST_CLS = CstockProject
JSON_FILES_DIR = f"{Path(__file__).parent}/json_files/project"
FILE_DIR_SUCCESS = f"{JSON_FILES_DIR}/success"
FILE_DIR_FAILURE = f"{JSON_FILES_DIR}/failure"
FILES_TO_TEST_SUCCESS = _get_json_files_in_dir(FILE_DIR_SUCCESS)
FILES_TO_TEST_FAILURE = _get_json_files_in_dir(FILE_DIR_FAILURE)

# TODO move testing log intoa standalone module to be used in all test cases in case
# test logic needs to change?


def test_render_task_load_from_json_success() -> None:
    logger.info(f"Loading files: {FILES_TO_TEST_SUCCESS}")
    import sys

    logger.warning(f"{sys.version=}")
    for test_file in FILES_TO_TEST_SUCCESS:
        logger.info(f"Loading file: {test_file}")
        test_object = json_io.cstock_from_json(test_file, TEST_CLS)
        # json_data = json_io.load(test_file)
        # test_object = cstock_from_dict(json_data, TEST_CLS)


def test_render_task_load_from_json_failure() -> None:
    logger.info(f"Loading files: {FILES_TO_TEST_FAILURE}")
    for test_file in FILES_TO_TEST_FAILURE:
        with pytest.raises(
            (
                TypeError,
                errors.CstockUnknownTypeError,
                errors.CstockInstantiationError,
            )
        ):
            logger.info(f"Loading file: {test_file}")
            test_object = json_io.cstock_from_json(test_file, TEST_CLS)

==> ceonmedia-0.3.2.tar.gz: ceonmedia-0.3.2/tests/_tests_json_io/test_project.py <==
import logging
import pytest
from typing import Union
from uuid import UUID, uuid4
from pathlib import Path
from ceonmedia import CstockProject
from ceonmedia import json_io
from ceonmedia import errors

logger = logging.getLogger(__name__)


def _get_json_files_in_dir(dir_to_read: Union[str, Path]) -> list[Path]:
    if not Path(dir_to_read).is_dir():
        raise Exception(
            f"Could not get test files, dir does not exist: {dir_to_read}"
        )
    p = Path(dir_to_read).glob("**/*")
    files = [x for x in p if x.is_file()]
    if not files:
        raise Exception(f"No files found for testing in path: {dir_to_read}")
    return files


TEST_CLS = CstockProject
JSON_FILES_DIR = f"{Path(__file__).parent}/json_files/project"
FILE_DIR_SUCCESS = f"{JSON_FILES_DIR}/success"
FILE_DIR_FAILURE = f"{JSON_FILES_DIR}/failure"
FILES_TO_TEST_SUCCESS = _get_json_files_in_dir(FILE_DIR_SUCCESS)
FILES_TO_TEST_FAILURE = _get_json_files_in_dir(FILE_DIR_FAILURE)

# TODO move testing log intoa standalone module to be used in all test cases in case
# test logic needs to change?


def test_render_task_load_from_json_success() -> None:
    logger.info(f"Loading files: {FILES_TO_TEST_SUCCESS}")
    import sys

    logger.warning(f"{sys.version=}")
    for test_file in FILES_TO_TEST_SUCCESS:
        logger.info(f"Loading file: {test_file}")
        test_object = json_io.cstock_from_json(test_file, TEST_CLS)
        # json_data = json_io.load(test_file)
        # test_object = cstock_from_dict(json_data, TEST_CLS)


def test_render_task_load_from_json_failure() -> None:
    logger.info(f"Loading files: {FILES_TO_TEST_FAILURE}")
    for test_file in FILES_TO_TEST_FAILURE:
        with pytest.raises(
            (
                TypeError,
                errors.CstockUnknownTypeError,
                errors.CstockInstantiationError,
            )
        ):
            logger.info(f"Loading file: {test_file}")
            test_object = json_io.cstock_from_json(test_file, TEST_CLS)
